@@ -5,7 +5,7 @@ use warnings;
 package Story::Interact::PageSource;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001001';
+our $VERSION   = '0.001002';
 
 use Story::Interact::Page ();
 use Story::Interact::Syntax ();
@@ -18,24 +18,6 @@ use namespace::clean;
 
 requires 'get_source_code';
 
-has 'safe' => (
-	is        => 'ro',
-	isa       => Object,
-	builder   => 1,
-);
-
-sub _build_safe {
-	my $compartment = Safe->new;
-	$compartment->permit(
-		qw/ :base_core :base_mem :base_loop :base_math sprintf qr /
-	);
-	$compartment->share_from(
-		'Story::Interact::Syntax',
-		\@Story::Interact::Syntax::EXPORT,
-	);
-	return $compartment;
-}
-
 sub get_page {
 	my ( $self, $state, $page_id ) = @_;
 	my $code = $self->get_source_code( $page_id );
@@ -43,7 +25,7 @@ sub get_page {
 	return Story::Interact::Page->new( id => ':end' ) unless $code;
 
 	Story::Interact::Syntax::START( $state, $page_id );
-	$self->safe->reval( "$code; 1", 1 )
+	eval( "package Story::Interact::Syntax; use strict; $code; 1" )
 		or croak( "Died on page '$page_id': $@" );
 	return Story::Interact::Syntax::FINISH( $state );
 }
