@@ -5,7 +5,7 @@ use warnings;
 package Story::Interact::State;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001001';
+our $VERSION   = '0.001002';
 
 use Story::Interact::Character ();
 
@@ -39,7 +39,7 @@ has 'visited' => (
 
 sub BUILD {
 	my ( $self, $arg ) = @_;
-	$self->character->{player} = Story::Interact::Character->new( name => 'Anon' );
+	$self->define_npc( player => ( name => 'Anon' ) );
 }
 
 sub player {
@@ -47,6 +47,12 @@ sub player {
 	return $self->character->{player};
 }
 
+sub define_npc {
+	my ( $self, $code, %attrs ) = @_;
+	return if defined $self->character->{$code};
+	$self->character->{$code} = Story::Interact::Character->new( %attrs );
+}
+
 sub update_from_page {
 	my ( $self, $page ) = @_;
 	++$self->visited->{ $page->id };
